# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, ... }:

{
  services.django-apps.sites.bocal = {
    source = "https://git.dgnum.eu/DGNum/www-bocal";
    branch = "main";
    domain = "bocal.cof.ens.fr";

    nginx = {
      enableACME = true;
      forceSSL = true;

      locations = {
        "/www/".root = "/users/guests/bocal/";
        "= /preparation.pdf".root = "/users/guests/bocal/www/";
        "~ /bocal_www/".extraConfig = ''
          rewrite ^/bocal_www(/.*)$ /www$1 last;
          try_files $uri $args;
        '';
      };
    };

    webHookSecret = config.age.secrets."webhook-bocal_token".path;

    overlays.nix-pkgs = [
      "django-cas-ng"
      "django-solo"
      "loadcredential"

      # Dependencies
      "python-cas"
    ];

    dependencies = ps: [
      ps.django
      ps.django-cas-ng
      ps.django-markdownx
      ps.django-solo
      ps.markdown
      ps.pillow
      ps.loadcredential
    ];

    credentials = {
      SECRET_KEY = config.age.secrets."dj_bocal-secret_key_file".path;
    };

    environment = {
      BOCAL_RHOSTS_PATH = "/users/guests/bocal/.rhosts";
    };
  };
}
