# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, ... }:

{
  services.django-apps.sites.gestiojeux = {
    source = "https://git.dgnum.eu/DGNum/gestiojeux";
    branch = "production";
    domain = "jeux.cof.ens.fr";

    nginx = {
      enableACME = true;
      forceSSL = true;
    };

    webHookSecret = config.age.secrets."webhook-gestiojeux_token".path;

    application = {
      type = "wsgi";
      module = "gestiojeux";
    };

    overlays.nix-pkgs = [
      "django-autoslug"
      "django-cas-ng"
      "loadcredential"
      "markdown-icons"

      # Dependencies
      "python-cas"
    ];

    django = ps: ps.django_4;
    dependencies = ps: [
      ps.django-autoslug
      ps.loadcredential
      ps.django-cas-ng
      ps.django-cleanup
      ps.django-haystack
      ps.django-markdownx
      ps.django-tables2
      ps.pillow
      ps.psycopg2
      ps.whoosh
      ps.markdown-icons

      # Django haystack is drunk
      ps.setuptools
    ];

    staticDirectory = "source/public/static";
    mediaDirectory = "source/public/media";

    credentials = {
      SECRET_KEY = config.age.secrets."dj_gestiojeux-secret_key_file".path;
      EMAIL_HOST = config.age.secrets."dj_gestiojeux-email_host_file".path;
    };

    environment = {
      GESTIOJEUX_SERVER_EMAIL = "gestiojeux@jeux.cof.ens.fr";
    };
  };
}
